summaryrefslogtreecommitdiffstats
path: root/chrome/browser/tab_contents/confirm_infobar_delegate.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/tab_contents/confirm_infobar_delegate.h')
-rw-r--r--chrome/browser/tab_contents/confirm_infobar_delegate.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/chrome/browser/tab_contents/confirm_infobar_delegate.h b/chrome/browser/tab_contents/confirm_infobar_delegate.h
index 07a9f3d..694ff28 100644
--- a/chrome/browser/tab_contents/confirm_infobar_delegate.h
+++ b/chrome/browser/tab_contents/confirm_infobar_delegate.h
@@ -35,11 +35,12 @@ class ConfirmInfoBarDelegate : public InfoBarDelegate {
virtual bool NeedElevation(InfoBarButton button) const;
// Called when the OK button is pressed. If the function returns true, the
// InfoBarDelegate should be removed from the associated TabContents.
virtual bool Accept();
// Called when the Cancel button is pressed. If the function returns true,
// the InfoBarDelegate should be removed from the associated TabContents.
virtual bool Cancel();
// Returns the text of the link to be displayed, if any. Otherwise returns
@@ -60,7 +61,7 @@ class ConfirmInfoBarDelegate : public InfoBarDelegate {
private:
// InfoBarDelegate:
- virtual InfoBar* CreateInfoBar() OVERRIDE;
+ virtual InfoBar* CreateInfoBar(TabContentsWrapper* owner) OVERRIDE;
virtual bool EqualsDelegate(InfoBarDelegate* delegate) const OVERRIDE;
virtual ConfirmInfoBarDelegate* AsConfirmInfoBarDelegate() OVERRIDE;
@@ -35,11 +35,12 @@ class ConfirmInfoBarDelegate : public InfoBarDelegate {
virtual bool NeedElevation(InfoBarButton button) const;
// Called when the OK button is pressed. If the function returns true, the
- // InfoBarDelegate should be removed from the associated TabContents.
+ // InfoBarDelegate should be removed from the associated TabContentsWrapper.
virtual bool Accept();
// Called when the Cancel button is pressed. If the function returns true,
@@ -35,11 +35,12 @@ class ConfirmInfoBarDelegate : public InfoBarDelegate {
virtual bool Accept();
// Called when the Cancel button is pressed. If the function returns true,
- // the InfoBarDelegate should be removed from the associated TabContents.
+ // the InfoBarDelegate should be removed from the associated
+ // TabContentsWrapper.
virtual bool Cancel();
// Returns the text of the link to be displayed, if any. Otherwise returns